==> nextcloud-24.0.9.tgz: nextcloud/apps/password_policy/l10n/de_DE.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Das Passwort ist abgelaufen, bitte die Methode \"Passwort vergessen\" zum Zurücksetzen verwenden",
    "Password must not have been used recently before." : "Das Passwort darf noch nicht verwendet worden sein.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Das Passwort ist unter den 1.000.000 häufigsten Passwörtern. Bitte wählen Sie ein anderes.",
    "Password is present in compromised password list. Please choose a different password." : "Das Passwort ist in der Liste der kompromittierten Passwörter enthalten. Bitte wählen Sie ein anderes Passwort.",
    "Password needs to be at least %s characters long." : "Das Passwort muss mindestens %s Zeichen lang sein.",
    "Password needs to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten. ",
    "Password needs to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten. ",
    "Password needs to contain at least one lower and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten.",
    "Password policy" : "Passwort-Regeln",
    "Allows admins to configure a password policy" : "Ermöglicht Administratoren eine Passwortrichtlinie einzurichten",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Ermöglicht Administratoren diverse Voreinstellungen für Passwörter vorzunehmen, z. B. die Mindestlänge",
    "Saved" : "Gespeichert",
    "Minimum password length" : "Minimale Passwortlänge",
    "User password history" : "Benutzerpasswort-Verlauf",
    "Number of days until user password expires" : "Anzahl der Tage bis zum Ablauf des Benutzerpassworts",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Anzahl der Anmeldeversuche, bevor das Benutzerkonto gesperrt wird (0 für unbegrenzte Anzahl)",
    "Forbid common passwords" : "Häufig verwendete Passwörter verbieten",
    "Enforce upper and lower case characters" : "Groß- und Kleinbuchstaben erzwingen",
    "Enforce numeric characters" : "Zahlen erzwingen",
    "Enforce special characters" : "Sonderzeichen erzwingen",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Das Passwort gegen eine Liste von geknackten Passwörtern bei haveibeenpwned.com prüfen.",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Es wird ein Hash des Passwortes erstellt und dessen ersten 5 Zeichen an haveibeenpwned.com gesendet. Danach wird eine Liste aller Hashes empfangen, welche mit diesen 5 Zeichen beginnen. Nextcloud prüft nun, ob der Hash des eingegebenen Passwortes in der Liste der Hashes enthalten ist.",
    "Unknown error" : "Unbekannter Fehler",
    "Minimal length has to be a non negative number" : "Minimale Länge muss eine nicht negative Zahl sein",
    "History size has to be a non negative number" : "Historiengröße muss eine nicht negative Zahl sein",
    "Expiration days have to be a non negative number" : "Verfallstage müssen eine nicht negative Zahl sein",
    "Maximum login attempts have to be a non negative number" : "Maximale Anmeldeversuche muss eine nicht negative Zahl sein",
    "Error while saving" : "Fehler beim Speichern"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/password_policy/l10n/de_DE.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Das Passwort ist abgelaufen, bitte die Methode \"Passwort vergessen\" zum Zurücksetzen verwenden",
    "Password must not have been used recently before." : "Das Passwort darf noch nicht verwendet worden sein.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Das Passwort ist unter den 1.000.000 häufigsten Passwörtern. Bitte wählen Sie ein anderes.",
    "Password is present in compromised password list. Please choose a different password." : "Das Passwort ist in der Liste der kompromittierten Passwörter enthalten. Bitte wählen Sie ein anderes Passwort.",
    "Password needs to be at least %s characters long." : "Das Passwort muss mindestens %s Zeichen lang sein.",
    "Password needs to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten. ",
    "Password needs to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten. ",
    "Password needs to contain at least one lower and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten.",
    "Password policy" : "Passwort-Regeln",
    "Allows admins to configure a password policy" : "Ermöglicht Administratoren eine Passwortrichtlinie einzurichten",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Ermöglicht Administratoren diverse Voreinstellungen für Passwörter vorzunehmen, z. B. die Mindestlänge",
    "Saved" : "Gespeichert",
    "Minimum password length" : "Minimale Passwortlänge",
    "User password history" : "Benutzerpasswort-Verlauf",
    "Number of days until user password expires" : "Anzahl der Tage bis zum Ablauf des Benutzerpassworts",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Anzahl der Anmeldeversuche, bevor das Benutzerkonto gesperrt wird (0 für unbegrenzte Anzahl)",
    "Forbid common passwords" : "Häufig verwendete Passwörter verbieten",
    "Enforce upper and lower case characters" : "Groß- und Kleinbuchstaben erzwingen",
    "Enforce numeric characters" : "Zahlen erzwingen",
    "Enforce special characters" : "Sonderzeichen erzwingen",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Das Passwort gegen eine Liste von geknackten Passwörtern bei haveibeenpwned.com prüfen.",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Es wird ein Hash des Passwortes erstellt und dessen erste 5 Zeichen an haveibeenpwned.com gesendet. Danach wird eine Liste aller Hashes empfangen, welche mit diesen 5 Zeichen beginnen. Nextcloud prüft nun, ob der Hash des eingegebenen Passwortes in der Liste der Hashes enthalten ist.",
    "Unknown error" : "Unbekannter Fehler",
    "Minimal length has to be a non negative number" : "Minimale Länge muss eine nicht negative Zahl sein",
    "History size has to be a non negative number" : "Historiengröße muss eine nicht negative Zahl sein",
    "Expiration days have to be a non negative number" : "Verfallstage müssen eine nicht negative Zahl sein",
    "Maximum login attempts have to be a non negative number" : "Maximale Anmeldeversuche muss eine nicht negative Zahl sein",
    "Error while saving" : "Fehler beim Speichern"
},
"nplurals=2; plural=(n != 1);");
